> ![MikroE](http://www.mikroe.com/img/designs/beta/logo_small.png)
> #Heartrate 3 Click#
> ##By [MikroElektronika](http://www.mikroe.com)
---

## Installation
Use the package manager to install the library for your architecture.

###Example on PIC
```
#include <stdint.h>
#include "heartrate_3.h"

// HeartRate 3 GPIO
sbit RST at RC0_bit;
sbit RST_DIR at TRISC0_bit;

void system_setup( void );
void InitTimer0( void );

uint8_t int_flag = 0;
uint16_t timer_count = 0;

void system_setup( void )
{
    //Local Declarations
    char            text[40] = { 0 };
    dynamic_modes_t dynamic_modes;
    uint8_t         address = 0x58;

    //Set up dynamic modes for Heart Rate 3 Initialization
    dynamic_modes.transmit = trans_dis;                      //Transmitter disabled
    dynamic_modes.curr_range = led_double;                   //LED range 0 - 100
    dynamic_modes.adc_power = adc_on;                        //ADC on
    dynamic_modes.clk_mode = osc_mode;                       //Use internal Oscillator
    dynamic_modes.tia_power = tia_off;                       //TIA off
    dynamic_modes.rest_of_adc = rest_of_adc_off;             //Rest of ADC off
    dynamic_modes.afe_rx_mode = afe_rx_normal;               //Normal Receiving on AFE
    dynamic_modes.afe_mode = afe_normal;                     //Normal AFE functionality

    //GPIO setup
    RST_DIR = 0;

    //UART Initialize
    UART1_Init( 9600 );
    Delay_ms(100);
    UART1_Write_Text( "UART is Initialized\r\n" );

    //Toggle Reset pin
    RST = 1;
    Delay_ms(50);
    RST = 0;

    //I2C Initialize
    I2C1_Init(100000);
    Delay_ms(150);
    UART1_Write_Text( "I2C Initialized\r\n" );

    //Heart Rate 3 Initialize
    hr3_init( address, &dynamic_modes );
    UART1_Write_Text( "HR3 Initialized\r\n" );

    initStatHRM();      // Initializes values to 0

    InitTimer0();
}

void InitTimer0() {
    T0CON         = 0x88;
    TMR0H         = 0x63;
    TMR0L         = 0xC0;
    GIE_bit         = 1;
    TMR0IE_bit         = 1;
}

void Interrupt()
{
    if (TMR0IF_bit) {
        TMR0IF_bit = 0;
        TMR0L         = 0x06;
        //Enter your code here
        int_flag = 1;
    }
}

```

```
void main()
{   //Local Declarations
    uint16_t   rate          = 0;
    char       uart_text[20] = {0};


    system_setup();     // GPIO / HeartRate 3 / UART / I2C Setups
    Delay_ms(200);

    while (1)
    {
        //UART1_Write_Text( "Got past initialization\r\n" );
        if ( int_flag == 1 )
        {
            statHRMAlgo( hr3_get_led1_val() );
            int_flag = 0;
            rate = hr3_get_heartrate();                                   // Gets current Heartrate

            LongWordToStr( rate, uart_text );
            UART1_Write_Text( uart_text );
            UART1_Write(13);
            UART1_Write(10);
        }
    }
}

```

